==> antiright-2.99.6.tar.bz2: antiright/gtkshell/updated_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

extern GSList *gsh_updater_list;
gboolean gsh_is_updating=FALSE;

void
gsh_test_updating()
{
	if(!gsh_is_updating)
        {
            gsh_start_updates();
		    gsh_is_updating=TRUE;
        }
}

void
gsh_updater_argument_generic(int argc, unsigned int *counter)
{
    gsh_count(argc, counter);
    gsh_test_updating();
}

void
gsh_handle_updated_arguments(int argc, char **argv, unsigned int *counter)
{
	assert(strlen(argv[(*counter)])>2);
	switch(argv[(*counter)][3])
	{
		case 'l':
			gsh_add_updated_label(argv[*counter+1]);
            gsh_updater_argument_generic(argc, counter);
			break;
		case 'p':
            gsh_add_updated_progress(argv[*counter+1]);
            gsh_updater_argument_generic(argc, counter);
			break;
	}
}

==> antiright-2.99.7.tar.bz2: antiright/gtkshell/updated_options.c <==
/*
  AntiRight
  (c) 2002-2006 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#include "gtkshell.h"

void
gsh_test_updating(struct GSH *gsh)
{
	if(!gsh->flags.updating)
        {
            gsh_start_updates();
	    gsh->flags.updating=TRUE;
        }
}

void
gsh_updater_argument_generic(struct GSH *gsh, int argc, unsigned int *counter)
{
    gsh_count(argc, counter);
    gsh_test_updating(gsh);
}

void
gsh_handle_updated_arguments(struct GSH *gsh, int argc, 
	char **argv, int *counter)
{
	assert(strlen(argv[(*counter)])>2);
	switch(argv[(*counter)][3])
	{
		case 'l':
			gsh_add_updated_label(gsh, argv[*counter+1]);
            		gsh_updater_argument_generic(gsh, argc, counter);
			break;
		case 'p':
            		gsh_add_updated_progress(gsh, argv[*counter+1]);
            		gsh_updater_argument_generic(gsh, argc, counter);
			break;
	}
}
